<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation>Du måste köra detta program som root</translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="443"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot-reparation</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Boot-reparation är ett redskap som kan användas för att återinstallera GRUB bootloader på ESP (EFI System Partition), MBR (Master Boot Record) eller root partitionen. Det ger möjligheten att rekonstruera GRUBs konfigurationsfil och att säkerhetskopiera och återställa MBR eller PBR (root).</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Vad vill du göra?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Säkerhetskopiera MBR eller PBR (enbart för legacy boot)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Återinstallera GRUB bootloader på ESP, MBR eller PBR (root)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Reparera GRUBs konfigurationsfil</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Återställ MBR eller PBR från säkerhetskopia (enbart för legacy boot) </translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="376"/>
        <source>Select Boot Method</source>
        <translation>Välj Boot-metod</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="417"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="378"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="377"/>
        <source>Install on:</source>
        <translation>Installera på:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation>Plats:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation>Välj /boot plats:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation>EFI System Partition</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="459"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="462"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="469"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="510"/>
        <source>Cancel any changes then quit</source>
        <translation>Avbryt ändringarna och sedan sluta</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="513"/>
        <location filename="../mxbootrepair.cpp" line="449"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="520"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="539"/>
        <source>Apply any changes</source>
        <translation>Genomför ändringar</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <location filename="../mxbootrepair.cpp" line="76"/>
        <source>Apply</source>
        <translation>Genomför</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="94"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB blir installerad på %1 enhet.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="109"/>
        <location filename="../mxbootrepair.cpp" line="132"/>
        <location filename="../mxbootrepair.cpp" line="162"/>
        <location filename="../mxbootrepair.cpp" line="264"/>
        <location filename="../mxbootrepair.cpp" line="298"/>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="110"/>
        <source>Could not mount </source>
        <translation>Kunde inte montera</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="110"/>
        <source> on /boot/efi</source>
        <translation>vid /boot/efi</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="133"/>
        <location filename="../mxbootrepair.cpp" line="163"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Kunde inte arrangera chroot-miljön.
Var vänlig dubbelkolla den valda platsen.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="150"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>GRUB konfigurationsfil (grub.cfg) återuppbyggs.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="184"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Backar upp MBR eller PBR från %1 enhet.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="239"/>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <source>You are going to write the content of </source>
        <translation>Du kommer att skriva innehållet av</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <source> to </source>
        <translation>till</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="240"/>
        <source>

Are you sure?</source>
        <translation>

Är du säker?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">Nej</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="245"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Återställer MBR/PBR från backup till %1 enhet.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="265"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Kunde inte hitta EFI system partition (ESP) på någon systemdisk. Var vänlig och skapa en ESP och försök igen.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="292"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="293"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Processen avslutades med framgång.&lt;p&gt;&lt;b&gt;Vill du avsluta MX Boot-reparation?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="299"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Processen avslutad. Fel har inträffat.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="301"/>
        <source>Back</source>
        <translation>Tillbaka</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="385"/>
        <source>Select GRUB location</source>
        <translation>Välj plats för GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="396"/>
        <source>Select Item to Back Up</source>
        <translation>Välj objekt att backa upp</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="403"/>
        <source>Select Item to Restore</source>
        <translation>Välj objekt att Återställa</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="414"/>
        <source>Select backup file name</source>
        <translation>Välj filnamn på säkerhetskopian</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>No file was selected.</source>
        <translation>Ingen fil valdes.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="421"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Välj MBR eller PBR säkerhetskopia</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="442"/>
        <source>About MX Boot Repair</source>
        <translation>Om MX Boot-reparation</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="443"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Enkelt boot-reparationsprogram för MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="446"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="470"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
</context>
</TS>
